@@ -25,7 +25,7 @@
  */
 
 static char     _devperf_id[] =
-    "$Id: devperf.c,v 1.11 2003/11/30 10:33:15 RogerSeguin Exp $";
+    "$Id: devperf.c,v 1.8 2003/11/30 10:58:54 rogerms Exp $";
 
 
 #define DEBUG	0
@@ -292,8 +292,15 @@ int DevGetPerfData (const void *p_pvDevice, struct devperf_t *perf)
 	gettimeofday (&tv, 0);
 	perf->timestamp_ns = (uint64_t)1000ull * 1000ull * 1000ull *
 		tv.tv_sec + 1000ull * tv.tv_usec;
+#if defined(__NetBSD_Version__) && (__NetBSD_Version__ < 106110000)
+  /* NetBSD < 1.6K does not have separate read/write statistics. */
+	perf->rbytes = drive.dk_bytes;
+	perf->wbytes = drive.dk_bytes;
+#else
 	perf->rbytes = drive.dk_rbytes;
 	perf->wbytes = drive.dk_wbytes;
+#endif
+
   /*
    * XXX - Currently, I don't know of any way to determine write/read busy
    * time separatly.
@@ -322,12 +329,12 @@ int DevGetPerfData (const void *p_pvDevice, struct devperf_t *perf)
 
 /*
 $Log: devperf.c,v $
-Revision 1.11  2003/11/30 10:33:15  RogerSeguin
-Fixed Linux 2.6 typo bug - Thanks to Ivan Todoroski
-DiskPerf 1.4.1
+Revision 1.8  2003/11/30 10:58:54  rogerms
+Release DiskPerf 1.4.1 - Just a bug fix for Linux-2.6 systems
+Thanks to Ivan Todoroski who found a bug introduced with release 1.3
 
-Revision 1.10  2003/11/11 12:17:58  RogerSeguin
-"Busy time" support added for NetBSD by Benedikt Meurer
+Revision 1.7  2003/11/17 09:24:14  benny
+NetBSD < 1.6K does not have separate read/write statistics. Thanks to martti.
 
 Revision 1.6  2003/11/10 23:00:41  benny
 Added "busy time" support for NetBSD.
